##
##  telegraf.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_telegraf_base  1.23.2
%define       V_telegraf_snap  20220721

#   package information
Name:         telegraf
Summary:      Time-Series Data Collection
URL:          https://influxdata.com/time-series-platform/telegraf/
Vendor:       InfluxData
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      MIT
Version:      %{V_telegraf_base}.%{V_telegraf_snap}
Release:      20220722

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/telegraf/telegraf-%{V_telegraf_snap}.tar.xz
Source1:      rc.telegraf
Source2:      telegraf.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Telegraf is a source agent for collecting metrics and data on the
    system it's running on or from other services. Telegraf writes data
    it collects to InfluxDB in the correct format.

%track
    prog telegraf = {
        version   = %{V_telegraf_base}
        url       = https://github.com/influxdata/telegraf/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n telegraf

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/influxdata/telegraf
        rm -f cmd/telegraf/telegraf_windows.go
        go build -v -o telegraf cmd/telegraf/*.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/telegraf/telegraf.d \
        $RPM_BUILD_ROOT%{l_prefix}/var/telegraf/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/telegraf/log

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/influxdata/telegraf/telegraf \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.telegraf} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE telegraf.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/telegraf/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/telegraf/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/telegraf/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/telegraf/*/*'

%files -f files

%clean

%post
    if [ $1 -eq 1 ]; then
        #   create input logfile
        su - %{l_rusr} -c \
            "touch $RPM_INSTALL_PREFIX/var/telegraf/log/telegraf.input.log"
    elif [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} telegraf status 2>/dev/null`
        [ ".$telegraf_active" = .yes ] && %{l_rc} telegraf restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove log files
        %{l_rc} telegraf stop 2>/dev/null
        rm -rf $RPM_INSTALL_PREFIX/var/telegraf/log/* >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/telegraf/run/* >/dev/null 2>&1 || true
    fi
    exit 0

